
# Device definitions for some pretend robots to be used in simple
# player/stage exercises that link to the early agent exercises in
# the Nilson AI textbook.
#
# Simon Parsons
# 18th January 2009

# Both robots are omnidiretional, the idea being that they can be driven 
# around using something like the north-south-east-west commands that Nilson
# uses.

# A square robot

# The sonar are as follows, > denotes the front of the robot
# 
#           0   
#         +---+
#       3 |  >| 1
#         +---+
#           2
#

define tetrabot_sonar ranger
(
  scount 4

  # define the pose of each transducer [xpos ypos heading]
  spose[0] [  0.0    0.125  90  ]
  spose[1] [  0.125  0.0     0  ]
  spose[2] [  0.0   -0.125 -90  ]
  spose[3] [ -0.125  0      180 ]
		
  # define the field of view of each transducer to be the same as for
  # the Activmedia/Mobilerobots devices [range_min range_max view_angle]
  sview [0 5.0 15]

  # define the size of each transducer [xsize ysize] in meters, again the
  # same as the Activmedia/Mobilerobots devices.
  ssize [0.01 0.05]
)

define tetrabot position
(
  size [0.25 0.25]

  # the robot's center of rotation is offset from its center of area
  origin [0.0 0.0 0.0]

  # draw a nose on the robot so we can see which way it points
  gui_nose 1

  # mass in KG
  mass 2.0 

  # unit square body shape
  polygons 1
  polygon[0].points 4
  polygon[0].point[0] [0 0]
  polygon[0].point[1] [0 1]
  polygon[0].point[2] [1 1]
  polygon[0].point[3] [1 0]

  # steering model
  drive "omni"

  # uncomment this line if you want to model real pioneers with SICK
  # lasers, where the laser is taller than the robot
  # laser_return 0

  # use the sonar array defined above
  tetrabot_sonar()  
) 

# Now an octoagonal omnidirectional robot

# The sonar are as follows, > denotes the front of the robot
#
#      7    0    1
#         /---\
#      6  |  > | 2
#         \---/
#      5    4    3
#

define octabot_sonar ranger
(
  scount 8

  # define the pose of each transducer [xpos ypos heading]
  spose[0] [  0.0    0.2  90  ]
  spose[1] [  0.133  0.133  45  ]
  spose[2] [  0.2  0.0     0  ]
  spose[3] [  0.133    -0.133  -45  ]
  spose[4] [  0.0   -0.2 -90  ]
  spose[5] [ -0.133 -0.133  -135  ]
  spose[6] [ -0.2  0      180 ]
  spose[7] [ -0.133    0.133  135  ]
		
  # define the field of view of each transducer to be the same as for
  # the Activmedia/Mobilerobots devices [range_min range_max view_angle]
  sview [0 5.0 15]

  # define the size of each transducer [xsize ysize] in meters, again the
  # same as the Activmedia/Mobilerobots devices.
  ssize [0.01 0.05]
)

define octabot position
(
  size [0.4 0.4]

  # the robot's center of rotation is not offset from its center of area
  origin [0.0 0.0 0.0]

  # draw a nose on the robot so we can see which way it points
  gui_nose 1

  # mass in KG
  mass 5.0 

  # simple octagonal body shape
  polygons 1
  polygon[0].points 8
  polygon[0].point[0] [0 0]
  polygon[0].point[1] [1 0]
  polygon[0].point[2] [2 1]
  polygon[0].point[3] [2 2]
  polygon[0].point[4] [1 3]
  polygon[0].point[5] [0 3]
  polygon[0].point[6] [-1 2]
  polygon[0].point[7] [-1 1]

  # steering model
  drive "omni"

  # uncomment this line if you want to model real pioneers with SICK
  # lasers, where the laser is taller than the robot
  # laser_return 0

  # use the sonar array defined above
  octabot_sonar()  
) 