//--------------------------------------------------------------------
//
// wall-follow.cc
//
// Example player libplayerc++ controller to make a simple wall
// following controller that uses sonar for an omnidirectional robot.
//
//
// This skeleton written: 18th January 2008
// Written by: Simon Parsons
//
// Usage: 
// 
// wall-follow [-h <host>] [-p <port>] [-i <index>] [-m] 
//		       
//  -h <host> : connect to Player on this host	 
//  -p <port> : connect to Player on this TCP port
//  -i <index>: connect to this device (default 0)
//  -m        : turn on motors

//--------------------------------------------------------------------

#include <iostream>
#include <libplayerc++/playerc++.h>

#include "args.h" // Code that allows us to handle standard arguments

using namespace PlayerCc;

//--------------------------------------------------------------------

int main(int argc, char *argv[])
{
  //------------------------------------------------------------------
  //
  // Variables

  // For setting speed

  player_pose2d speed;

  const  double stdSpeed = 0.4;
  double xSpeed;
  double ySpeed;
  double tSpeed;

  //------------------------------------------------------------------

  // Parse the arguments and set up the relevant variables.
  parse_args(argc,argv); 

  // Use the arguments to connect to the specified device.
  PlayerClient robot (gHostname, gPort);
  Position2dProxy pp (&robot, gIndex);
  SonarProxy sp (&robot, gIndex);

  // Control loop starts

  while(true)
  {
    // Read sensor values. This reads new sensor values into the array sp
    robot.Read();

    // Print out the sonar values. The sonar readings are an array of 8 
    // values
    std::cout << "Sonar" << std::endl;
    std::cout << sp[0] << std::endl << sp[1] << std::endl;
    std::cout << sp[2] << std::endl << sp[3] << std::endl;
    std::cout << sp[4] << std::endl << sp[5] << std::endl;
    std::cout << sp[6] << std::endl << sp[7] << std::endl << std::endl;

    // Start with speed zero
    xSpeed = 0;
    ySpeed = 0;
    tSpeed = 0;

    // In here you need to write your controller!

    // Setup speed values to send them to the robot.
    // speed.px is speed in the x direction
    // speed.py is speed in the y direction
    // speed.pa is rotational speed.
    speed.px = xSpeed;
    speed.py = ySpeed;
    speed.pa = tSpeed;

    // Now use those values to drive the robot
    pp.SetSpeed(speed);
  }

  // Control loop ends
}
